@@ -3,7 +3,7 @@ BEGIN {
   $Tapper::MCP::Child::AUTHORITY = 'cpan:AMD';
 }
 {
-  $Tapper::MCP::Child::VERSION = '4.0.4';
+  $Tapper::MCP::Child::VERSION = '4.0.5';
 }
 # ABSTRACT: Control one specific testrun on MCP side
 
@@ -25,7 +25,6 @@ use Devel::Backtrace;
 
 use constant BUFLEN     => 1024;
 use constant ONE_MINUTE => 60;
-use constant HARNESS_ACTIVE => 0;#$ENV{HARNESS_ACTIVE};
 
 extends 'Tapper::MCP::Control';
 with 'Tapper::MCP::Net::TAP';
@@ -45,7 +44,7 @@ sub get_messages
         while () {
                 $messages = $self->testrun->message;
                 last if ($messages and $messages->count) or time() > $end_time;
-                sleep 1 unless HARNESS_ACTIVE;
+                sleep 1 unless $ENV{HARNESS_ACTIVE};
         }
         return $messages;
 }
