@@ -3,13 +3,13 @@ BEGIN {
   $Tapper::MCP::Net::Reset::OSRC::AUTHORITY = 'cpan:AMD';
 }
 {
-  $Tapper::MCP::Net::Reset::OSRC::VERSION = '4.0.4';
+  $Tapper::MCP::Net::Reset::OSRC::VERSION = '4.0.5';
 }
 
 use strict;
 use warnings;
 
-use File::Temp;
+use File::Temp qw"tempfile tempdir";
 use File::Spec;
 use Net::OpenSSH;
 use Moose;
@@ -60,10 +60,9 @@ sub reset_host
                 $self->log->warn("TFTP log '$log' is zero size!");
         }
 
-        my $logbefore =
-         File::Temp
-                  ->new(TEMPLATE => "osrcreset-tftplog-before-XXXXXX", DIR => File::Spec->tmpdir)
-                   ->filename;
+        my $tmpdir = tempdir( CLEANUP => 1 );
+        my $tmplog = File::Temp->new(TEMPLATE => "osrcreset-tftplog-before-XXXXXX", DIR => $tmpdir, UNLINK => 1);
+        my $logbefore = $tmplog->filename;
 
         # store tftp log before reboot
         $self->log_and_exec("cp $log $logbefore");
@@ -92,6 +91,8 @@ sub reset_host
 
                 ($error, $retval) = $self->log_and_exec($cmd);
         }
+        undef $tmplog;
+        rmdir $tmpdir;
         return ($error, $retval);
 }
 
